/**
 * Copyright 2011 Thorsten Höger, Taimos GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.taimos.jsonrpc.client;

import de.taimos.jsonrpc.msg.IResponse;
import de.taimos.jsonrpc.msg.NotificationRequest;
import de.taimos.jsonrpc.msg.RPCRequest;

/**
 * Interface for generic ServerConnectors to be used in {@link RPCProxyFactory}
 * 
 * @author Thorsten Hoeger
 */
public interface IServerConnector {
	
	/**
	 * execute a JSON-RPC notification with given request and no response
	 * 
	 * @param _notification - the notification to send to the server
	 */
	void doNotify(NotificationRequest _notification);
	
	/**
	 * execute a JSON-RPC request with given request
	 * 
	 * @param _notification - the notification to send to the server
	 * @return the response object
	 */
	IResponse doRPC(RPCRequest _notification);
	
}
