/**
 * Copyright 2011 Thorsten Höger, Taimos GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.taimos.jsonrpc.msg;

import java.util.HashMap;

/**
 * Interface for all JSON-RPC requests
 * 
 * @author Thorsten Hoeger
 */
public interface IRequest {
	
	/**
	 * Returns the used JSON-RPC version
	 * 
	 * @return the jsonrpc version
	 */
	String getVersion();
	
	/**
	 * Returns the name of the method to execute
	 * 
	 * @return the method name
	 */
	String getMethod();
	
	/**
	 * Returns the map of invocation parameters
	 * 
	 * @return the optional method parameters
	 */
	HashMap<String, Object> getParams();
	
}
