/**
 * Copyright 2011 Thorsten Höger, Taimos GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.taimos.jsonrpc.msg;

import java.util.HashMap;

import org.codehaus.jackson.annotate.JsonCreator;
import org.codehaus.jackson.annotate.JsonProperty;

/**
 * This class represents a JSON-RPC notification
 * 
 * @author Thorsten Hoeger
 */
public class NotificationRequest implements IRequest {
	
	private String method = "";
	
	private HashMap<String, Object> params = null;
	

	/**
	 * Creates a new empty notification
	 */
	public NotificationRequest() {
		//
	}
	
	/**
	 * Creates a new notification for the given method
	 * 
	 * @param _method - the target method
	 */
	public NotificationRequest(String _method) {
		this(_method, null);
	}
	
	/**
	 * Creates a new notification for the given method with supplied parameters
	 * 
	 * @param _method - the target method
	 * @param _params - the parameters
	 */
	@JsonCreator
	public NotificationRequest(@JsonProperty("method") String _method, @JsonProperty("params") HashMap<String, Object> _params) {
		this();
		this.method = _method;
		this.params = _params;
	}
	
	@Override
	@JsonProperty("jsonrpc")
	public String getVersion() {
		// given in spec
		return "2.0";
	}
	
	/**
	 * Setter for the version string. This HAS to be "2.0". Otherwise an
	 * {@link IllegalArgumentException} is thrown.
	 * 
	 * @param version
	 */
	@JsonProperty("jsonrpc")
	public void checkVersion(String version) {
		if (!version.equals("2.0")) {
			throw new IllegalArgumentException();
		}
	}
	
	@Override
	public String getMethod() {
		return this.method;
	}
	
	@Override
	public HashMap<String, Object> getParams() {
		return this.params;
	}
	
}
