/**
 * Copyright 2011 Thorsten Höger, Taimos GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.taimos.jsonrpc.msg;

import org.codehaus.jackson.annotate.JsonCreator;
import org.codehaus.jackson.annotate.JsonProperty;

/**
 * This class represents a received response
 * 
 * @author Thorsten Hoeger
 */
public class SuccessResponse implements IResponse {
	
	private Object id;
	
	private Object result;
	

	/**
	 * Creates a new empty response message
	 */
	public SuccessResponse() {
		//
	}
	
	/**
	 * Creates a new response message with given values
	 * 
	 * @param _id - the original request id
	 * @param _result - the result object
	 */
	@JsonCreator
	public SuccessResponse(@JsonProperty("id") Object _id, @JsonProperty("result") Object _result) {
		this();
		this.id = _id;
		this.result = _result;
	}
	
	@Override
	@JsonProperty("jsonrpc")
	public String getVersion() {
		return "2.0";
	}
	
	/**
	 * Setter for the version string. This HAS to be "2.0". Otherwise an
	 * {@link IllegalArgumentException} is thrown.
	 * 
	 * @param version
	 */
	@JsonProperty("jsonrpc")
	public void checkVersion(String version) {
		if (!version.equals("2.0")) {
			throw new IllegalArgumentException();
		}
	}
	
	@Override
	public Object getId() {
		return this.id;
	}
	
	/**
	 * Returns the response from the RPC
	 * 
	 * @return the result object
	 */
	public Object getResult() {
		return this.result;
	}
	
}
