/**
 * Copyright 2011 Thorsten Höger, Taimos GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package de.taimos.jsonrpc.test;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import de.taimos.jsonrpc.client.HTTPServerConnector;
import de.taimos.jsonrpc.client.RPCProxyFactory;
import de.taimos.jsonrpc.server.HTTPServer;
import de.taimos.jsonrpc.test.util.MyTestInterface;
import de.taimos.jsonrpc.test.util.MyTestInterfaceImpl;
import de.taimos.jsonrpc.test.util.SimpleObject;

/**
 * Copyright 2010 Taimos GmbH
 * 
 * @author Thorsten Hoeger
 */
public class Tester {
	
	private MyTestInterface proxy;
	
	private HTTPServer server;
	
	
	/**
	 * @throws Exception
	 */
	@Before
	public void setUp() throws Exception {
		this.server = new HTTPServer("localhost", 8888);
		this.server.addHandler(new MyTestInterfaceImpl());
		this.server.startServer();
		this.proxy = RPCProxyFactory.createProxy(MyTestInterface.class, new HTTPServerConnector("http://localhost:8888/json-rpc"), true);
	}
	
	/**
	 * 
	 */
	@Test(expected = InvocationTargetException.class)
	public void testFail() {
		this.proxy.iWillFail();
	}
	
	/**
	 * 
	 */
	@Test
	public void testFoo() {
		this.proxy.foo("Hello!");
	}
	
	/**
	 * 
	 */
	@Test
	public void testBla() {
		String bla = this.proxy.bla(42);
		Assert.assertEquals(bla, ">>42<<");
	}
	
	/**
	 * 
	 */
	@Test
	public void testSO() {
		SimpleObject so = new SimpleObject("foo", "bar");
		SimpleObject so2 = this.proxy.simple(so);
		Assert.assertEquals("Objects were different", so, so2);
	}
	
	/**
	 * 
	 */
	@Test
	public void testCollect() {
		ArrayList<SimpleObject> list = new ArrayList<SimpleObject>();
		list.add(new SimpleObject("foo", "foo"));
		list.add(new SimpleObject("bar", "bar"));
		list.add(new SimpleObject("blubb", "blubb"));
		String s = this.proxy.collect(list);
		Assert.assertEquals("foobarblubb", s);
	}
	
	/**
	 * 
	 */
	@Test
	public void testResArray() {
		ArrayList<SimpleObject> list = new ArrayList<SimpleObject>();
		list.add(new SimpleObject("foo", "foo"));
		list.add(new SimpleObject("bar", "bar"));
		list.add(new SimpleObject("blubb", "blubb"));
		String[] s = this.proxy.resArray(list);
		Assert.assertEquals(new String[] {"foo", "bar", "blubb"}, s);
	}
	
	/**
	 * 
	 */
	@Test
	public void testResList() {
		ArrayList<SimpleObject> list = new ArrayList<SimpleObject>();
		list.add(new SimpleObject("foo", "foo"));
		list.add(new SimpleObject("bar", "bar"));
		list.add(new SimpleObject("blubb", "blubb"));
		List<SimpleObject> s = this.proxy.resList(list);
		
		Assert.assertEquals(list, s);
	}
	
	/**
	 * @throws Exception
	 */
	@After
	public void tearDown() throws Exception {
		this.server.stopServer();
		this.server = null;
		this.proxy = null;
	}
	
}
